@@ -136,6 +136,7 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     echo "MANILA_OPTGROUP_adminnet_standalone_network_plugin_ip_version=4" >> $localconf
 
     export MANILA_TEMPEST_CONCURRENCY=24
+    export MANILA_CONFIGURE_DEFAULT_TYPES=False
 
 elif [[ "$DRIVER" == "lvm" ]]; then
     MANILA_SERVICE_IMAGE_ENABLED=True
@@ -163,7 +164,12 @@ elif [[ "$DRIVER" == "container"* ]]; then
 fi
 
 echo "MANILA_SERVICE_IMAGE_ENABLED=$MANILA_SERVICE_IMAGE_ENABLED" >> $localconf
+if [[ "$MANILA_SERVICE_IMAGE_ENABLED" == True ]]; then
+    echo "MANILA_SERVICE_IMAGE_URL=$MANILA_SERVICE_IMAGE_URL" >> $localconf
+    echo "MANILA_SERVICE_IMAGE_NAME=$MANILA_SERVICE_IMAGE_NAME" >> $localconf
+fi
 echo "MANILA_DEFAULT_SHARE_TYPE_EXTRA_SPECS=$DEFAULT_EXTRA_SPECS" >> $localconf
+echo "MANILA_CONFIGURE_DEFAULT_TYPES=${MANILA_CONFIGURE_DEFAULT_TYPES:-True}" >> $localconf
 
 # Enabling isolated metadata in Neutron is required because
 # Tempest creates isolated networks and created vm's in scenario tests don't
