@@ -123,12 +123,12 @@ class ShareMixin(object):
         """Returns a list of shares, transformed through view builder."""
         context = req.environ['manila.context']
 
+        common._validate_pagination_query(req)
+
         search_opts = {}
         search_opts.update(req.GET)
 
         # Remove keys that are not related to share attrs
-        search_opts.pop('limit', None)
-        search_opts.pop('offset', None)
         sort_key = search_opts.pop('sort_key', 'created_at')
         sort_dir = search_opts.pop('sort_dir', 'desc')
 
@@ -173,14 +173,10 @@ class ShareMixin(object):
         if show_count:
             total_count = len(shares)
 
-        limited_list = common.limited(shares, req)
-
         if is_detail:
-            shares = self._view_builder.detail_list(req, limited_list,
-                                                    total_count)
+            shares = self._view_builder.detail_list(req, shares, total_count)
         else:
-            shares = self._view_builder.summary_list(req, limited_list,
-                                                     total_count)
+            shares = self._view_builder.summary_list(req, shares, total_count)
         return shares
 
     def _get_share_search_options(self):
@@ -195,7 +191,7 @@ class ShareMixin(object):
             'is_public', 'metadata', 'extra_specs', 'sort_key', 'sort_dir',
             'share_group_id', 'share_group_snapshot_id', 'export_location_id',
             'export_location_path', 'display_name~', 'display_description~',
-            'display_description'
+            'display_description', 'limit', 'offset'
         )
 
     def update(self, req, id, body):
